/****************************************************************
Copyright (c) 1998 Sandro Sigala <ssigala@globalnet.it>.
All rights reserved.

Permission to use, copy, modify, and distribute this software
and its documentation for any purpose and without fee is hereby
granted, provided that the above copyright notice appear in all
copies and that both that the copyright notice and this
permission notice and warranty disclaimer appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

The author disclaim all warranties with regard to this
software, including all implied warranties of merchantability
and fitness.  In no event shall the author be liable for any
special, indirect or consequential damages or any damages
whatsoever resulting from loss of use, data or profits, whether
in an action of contract, negligence or other tortious action,
arising out of or in connection with the use or performance of
this software.
****************************************************************/

#include "config.h"

#include <qdir.h>
#include <kapp.h>
#include <qfile.h>
#include <qtstream.h>

#include "kreptoned.h"

void loadEpisodeList(QList<Episode>& l, bool global)
{
	QString path;

	if (global)
		path = kapp->kde_datadir() + "/krepton/data";
	else
		path = kapp->localkdedir() + "/share/apps/krepton/data";

	QDir dir(path);
	if (!dir.exists())
		if (global)
			fatal("Cannot open %s directory", (const char *)path);
		else
			return;
	dir.setFilter(QDir::Dirs);
	dir.setSorting(QDir::Name);
	const QFileInfoList *list = dir.entryInfoList();
	QFileInfoListIterator it(*list);
	QFileInfo *fi;
	while ((fi = it.current()) != 0) {
		if (fi->fileName() != "." && fi->fileName() != "..") {
			if (!dir.cd(fi->fileName()))
				fatal("Cannot enter directory %s",
				      (const char *)dir.absFilePath(fi->fileName()));
			QString filename = dir.absPath() + "/info";
			QFile f(filename);
			if (!f.open(IO_ReadOnly))
				fatal("Cannot open %s", (const char *)filename);
			QTextStream t(&f);
			QString name;
			name = t.readLine();
			name = name.stripWhiteSpace();
			f.close();
			dir.cdUp();
			Episode *e = new Episode(name, fi->fileName());
			e->global = global;
			l.append(e);
		}
		++it;
	}
}

int countUserEpisodes()
{
	QList<Episode> l;
	loadEpisodeList(l, false);
	return l.count();
}

void removeMapFiles(const QString& path)
{
	QDir dir(path);
	if (!dir.exists())
		fatal("cannot open directory %s", (const char *)path);
	dir.setFilter(QDir::Files);
	dir.setNameFilter("map*");
	dir.setSorting(QDir::Name);
	const QFileInfoList *list = dir.entryInfoList();
	QFileInfoListIterator it(*list);
	QFileInfo *fi;
	while ((fi = it.current()) != 0) {
		dir.remove(fi->fileName());
		++it;
	}
}

void removeEpisode(const QString& path)
{
	QDir dir(path);
	if (!dir.exists())
		fatal("cannot open directory %s", (const char *)path);
	QString dirname = dir.dirName();
	dir.setFilter(QDir::Files);
	dir.setSorting(QDir::Name);
	const QFileInfoList *list = dir.entryInfoList();
	QFileInfoListIterator it(*list);
	QFileInfo *fi;
	while ((fi = it.current()) != 0) {
		dir.remove(fi->fileName());
		++it;
	}
	dir.cdUp();
	dir.rmdir(path);
}

void createPath(const QString& destpath)
{
	// Create the destination directory
	QString filename;
	QDir dir(destpath);
	if (!dir.exists()) {
		filename = kapp->localkdedir() + "/share/apps/krepton";
		dir.mkdir(filename);
		filename = kapp->localkdedir() + "/share/apps/krepton/data";
		dir.mkdir(filename);
		dir.mkdir(destpath);
	}
	dir.cd(destpath);
	if (!dir.exists())
		fatal("cannot make directory %s", (const char *)destpath);
}

void copyFile(const QString& srcfile, const QString& destfile)
{
	QFile fin(srcfile), fout(destfile);

	if (!fin.open(IO_ReadOnly))
		fatal("Cannot open %s", (const char *)srcfile);
	if (!fout.open(IO_WriteOnly))
		fatal("Cannot open %s for writing", (const char *)destfile);

	char buf[1024];
	int i;
	while ((i = fin.readBlock(buf, 1024)) > 0)
		fout.writeBlock(buf, i);

	fin.close();
	fout.close();
}
